<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Editor::Internal::TableDialog</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="23"/>
        <source>Table creation</source>
        <translation>Création de tableau</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="42"/>
        <source>Rich Text Editor Table Creator</source>
        <translation>Assistant de création de tableau</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="65"/>
        <source>Size of the table</source>
        <translation>Taille du tableau</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="83"/>
        <source>Number of columns</source>
        <translation>Nombre de colonnes</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="143"/>
        <source>Number of rows</source>
        <translation>Nombre de lignes</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="200"/>
        <source>Format of the table</source>
        <translation>Format du tableau</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="218"/>
        <source>Cell spacing</source>
        <translation>Espacement des cellules</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="272"/>
        <source>Cell padding</source>
        <translation>Espacement dans la cellule</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="326"/>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="383"/>
        <source>Table headers</source>
        <translation>Entête de tableau</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="395"/>
        <source>You can define the first row as header. The table header row get repeated when a table is broken across a page boundary.</source>
        <translation>Vous pouvez définir la première ligne du tableau comme entête de tableau. Cette entête sera répétée si tableau se trouve coupé par un saut de page.</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="398"/>
        <source>Define the first row as header</source>
        <translation>Définir la première ligne comme entête de tableau</translation>
    </message>
</context>
<context>
    <name>Editor::Internal::TablePropertiesDialog</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertiesdialog.ui" line="14"/>
        <location filename="../../plugins/texteditorplugin/tablepropertiesdialog.ui" line="32"/>
        <source>Rich Text - Table Properties</source>
        <translation>Éditeur - Propriété du tableau</translation>
    </message>
</context>
<context>
    <name>Editor::Internal::TablePropertiesWidget</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="24"/>
        <source>Border / Space</source>
        <translation>Bordures et espacement</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="30"/>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="121"/>
        <source>Cell padding</source>
        <translation>Espacement dans la cellule</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="36"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="46"/>
        <source>Style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="62"/>
        <source>Adjust column size</source>
        <translation>Ajuster la taille des colonnes</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="72"/>
        <source>Adjust row size</source>
        <translation>Ajuster la taille des lignes</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="79"/>
        <source>Margins, Padding and spacing</source>
        <translation>Marges et espacements</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="99"/>
        <source>Margins (pix)</source>
        <translation>Marges (pixels)</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="114"/>
        <source>Cell spacing</source>
        <translation>Espacement des cellules</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="141"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="147"/>
        <source>Alterning rows color</source>
        <translation>Alterner les couleurs des lignes</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="154"/>
        <source>Border color</source>
        <translation>Couleur de la bordure</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="180"/>
        <source>Cells background color</source>
        <translation>Couleur de fond des cellules</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="44"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="45"/>
        <source>Dotted</source>
        <translation>Pointillés</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="46"/>
        <source>Dashed</source>
        <translation>Traits</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="47"/>
        <source>Solid</source>
        <translation>Solide</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="48"/>
        <source>Double</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="49"/>
        <source>Dot dash</source>
        <translation>Point trait</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="50"/>
        <source>Dot dot dash</source>
        <translation>Point point trait</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="51"/>
        <source>Groove</source>
        <translation>Rythmée</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="52"/>
        <source>Rigde</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="53"/>
        <source>Inset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="54"/>
        <source>Outset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Editor::TextEditor</name>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="500"/>
        <source>Save in pure textual format ?</source>
        <translation>Sauvegarder en format textuel ?</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="501"/>
        <source>The conversion of the document to a pure textual format will cause the lost of the paragraph and characters format. Do you really want to save in pure textual format ?</source>
        <translation>La conversion de ce document en format texte causera la perte du formattage des caractères et des paragraphes. Voulez-vous sauvegarder en mode textuel pure ?</translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="523"/>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="525"/>
        <source>Font format</source>
        <translation>Format de police</translation>
    </message>
</context>
</TS>
